:mod:`JMAPClient` -- JMAP calendar client
==========================================

.. automodule:: caldav.jmap.client
   :synopsis: Synchronous JMAP client for calendar operations
   :members:

.. automodule:: caldav.jmap.async_client
   :synopsis: Asynchronous JMAP client for calendar operations
   :members:
